<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
	xmlns="http://www.w3.org/1999/xhtml"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:ws="http://www.ebenoit.info/data"
	xmlns:wsf="http://www.ebenoit.info/ext">


	<!-- *********************************************************************************************** -->
	<!-- * UTILITY TEMPLATES                                                                           * -->
	<!-- *********************************************************************************************** -->


	<!-- Page title lookup
	   -
	   - This template attempts to find a page's title in the current language
	   - from the configuration. If the page is not found in the current language,
	   - it will try to use a site-wise title.
	   -
	   - Parameters:
	   -   id               The page's identifier
	  -->
	<xsl:template name="get-page-title">
		<xsl:param name="id" />
		<xsl:variable name="not-found">(title not found)</xsl:variable>

		<xsl:choose>

			<!-- Try the language-specific title -->
			<xsl:when test="$c-block/ws:pages/ws:page[ @id = $id and @title ]">
				<xsl:value-of select="$c-block/ws:pages/ws:page[ @id = $id ]/@title" />
			</xsl:when>

			<!-- Fallback to site-wise title -->
			<xsl:when test="$d/ws:sitemap/ws:page[ @id = $id and @title ]">
				<xsl:value-of select="$d/ws:sitemap/ws:page[ @id = $id and @title ]/@title" />
			</xsl:when>

			<!-- Fail. -->
			<xsl:otherwise>
				<xsl:value-of select="$not-found" />
			</xsl:otherwise>

		</xsl:choose>
	</xsl:template>


	<!-- String translator
	   -
	   - This template gets translations in the appropriate language for the various
	   - system strings.
	   -
	   - Parameters:
	   -   id               The string's identifier
	  -->
	<xsl:template name="get-i18n-string">
		<xsl:param name="id" />

		<xsl:variable name="not-found">(string not found)</xsl:variable>

		<xsl:choose>
			<!-- Has the string been inlined into the main configuration file? -->
			<xsl:when test="$c-block/ws:strings/ws:string[ @id = $id ]">
				<xsl:value-of select="$c-block/ws:strings/ws:string[ @id = $id ]" />
			</xsl:when>

			<!-- If there is a data file, look for the string in there -->
			<xsl:when test="$c-block/ws:strings/@datafile">
				<xsl:variable name="strings-file" select="document($c-block/ws:strings/@datafile)/ws:strings" />
				<xsl:choose>
					<!-- Is it in the strings file? -->
					<xsl:when test="$strings-file/ws:string[ @id = $id ]">
						<xsl:value-of select="$strings-file/ws:string[ @id = $id ]" />
					</xsl:when>
					<!-- No luck... -->
					<xsl:otherwise>
						<xsl:value-of select="$not-found" />
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>

			<!-- No luck... -->
			<xsl:otherwise>
				<xsl:value-of select="$not-found" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>


	<!-- JavaScript inclusion template
	   -
	   - This template generates the HTML code that includes a JavaScript file, using the paths
	   - specified inside the configuration.
	   -
	   - Parameters:
	   -   file             The name of the file (with no extension) to include
	  -->
	<xsl:template name="include-javascript">
		<xsl:param name="file" />

		<!-- Get the path to JavaScript files -->
		<xsl:variable name="js-path">
			<xsl:choose>
				<!-- Is there a path in the configuration? -->
				<xsl:when test="$d/ws:data-paths/ws:path-to[ @type='js' ]">
					<xsl:value-of select="$d/ws:data-paths/ws:path-to[ @type='js' ]" />
				</xsl:when>
				<!-- No, use the default -->
				<xsl:otherwise>js</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

		<script type='text/javascript' charset='utf-8'>
			<xsl:attribute name="src"><xsl:value-of select="concat($webRoot , $js-path , '/' , $file , '.js')" /></xsl:attribute>
			<xsl:text disable-output-escaping="yes">&lt;!--
			//--&gt;</xsl:text>
		</script>

	</xsl:template>


	<!-- CSS inclusion template
	   -
	   - This template generates the HTML code that includes a CSS file, using the paths
	   - specified inside the configuration.
	   -
	   - Parameters:
	   -   file             The name of the file (with no extension) to include
	  -->
	<xsl:template name="include-css">
		<xsl:param name="file" />

		<!-- Get the path to CSS files -->
		<xsl:variable name="css-path">
			<xsl:choose>
				<!-- Is there a path in the configuration? -->
				<xsl:when test="$d/ws:data-paths/ws:path-to[ @type='css' ]">
					<xsl:value-of select="$d/ws:data-paths/ws:path-to[ @type='css' ]" />
				</xsl:when>
				<!-- No, use the default -->
				<xsl:otherwise>css</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

		<link rel="stylesheet" type="text/css">
			<xsl:attribute name="href"><xsl:value-of select="concat( $webRoot , $css-path , '/' , $file , '.css')" /></xsl:attribute>
		</link>

	</xsl:template>


	<!-- Image source
	   -
	   - This template generates the path to an image.
	   -
	   - Parameters:
	   -   file             The name of the file
	  -->
	<xsl:template name="image-source">
		<xsl:param name="file" />

		<!-- Get the path to images -->
		<xsl:variable name="img-path">
			<xsl:choose>
				<!-- Is there a path in the configuration? -->
				<xsl:when test="$d/ws:data-paths/ws:path-to[ @type='img' ]">
					<xsl:value-of select="$d/ws:data-paths/ws:path-to[ @type='img' ]" />
				</xsl:when>
				<!-- No, use the default -->
				<xsl:otherwise>img</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

		<xsl:value-of select="concat( $webRoot , $img-path , '/' , $file)" />

	</xsl:template>

</xsl:stylesheet>